@@ -2,4 +2,4 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from r3sponse.v1.classes.r3sponse import Manager
\ No newline at end of file
+from r3sponse.v1.classes.r3sponse import r3sponse
\ No newline at end of file
