@@ -25,7 +25,7 @@ class R3sponse(object):
 		# save the error to the logs file.
 		save=False,
 	):
-		response = self.__default_response__()
+		response = self.default_response()
 		response["success"] = True
 		response["message"] = message
 		for key, value in variables.items():
@@ -41,7 +41,7 @@ class R3sponse(object):
 		# save the error to the erros file.
 		save=False,
 	):
-		response = self.__default_response__()
+		response = self.default_response()
 		response["error"] = error
 		if log: print(response["error"])
 		if save: self.__log_to_file__(response["error"])
@@ -71,7 +71,7 @@ class R3sponse(object):
 	def __log_to_file__(self, message):
 
 		# init.
-		response = self.__default_response__()
+		response = self.default_response()
 		try:
 			with open(self.log_file, "a") as file:
 				file.write(f'{Formats.Date().seconds_timestamp} - {message}\n')
